@@ -60,10 +60,6 @@ public:
     void setSocketTimeout(int ms);
     int socketTimeout() const;
 
-    bool canStartTls() const {
-        return q->state() == Session::NotAuthenticated && supportsStartTls;
-    }
-
 Q_SIGNALS:
     void encryptionNegotiationResult(bool);
 
@@ -120,8 +116,6 @@ private:
 
     int socketTimerInterval = 0;
     QTimer socketTimer;
-
-    bool supportsStartTls = false;
 };
 
 }
